#[repr(u8)]pub enum CkstatCkmode {
Show 16 variants
CKMODE0000 = 0,
CKMODE0001 = 1,
_RESERVED_2 = 2,
CKMODE0011 = 3,
_RESERVED_4 = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
CKMODE0111 = 7,
_RESERVED_8 = 8,
_RESERVED_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
CKMODE1111 = 15,
}Variants
CKMODE0000 = 0
Core clock is on
CKMODE0001 = 1
Core clock is off
_RESERVED_2 = 2
CKMODE0011 = 3
Core and platform clocks are off
_RESERVED_4 = 4
_RESERVED_5 = 5
_RESERVED_6 = 6
CKMODE0111 = 7
Core, platform, and peripheral clocks are off, but no change in Low-Power mode
_RESERVED_8 = 8
_RESERVED_9 = 9
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
CKMODE1111 = 15
Core, platform, and peripheral clocks are off, and core enters Low-Power mode
Implementations
Sourceimpl CkstatCkmode
impl CkstatCkmode